# Recurly

This library is the python client for Recurly's V3 API. It's currently in the "Early Access" phase of development.
To learn more about getting early access to the next iteration of our API ecosystem, see [this link](https://dev.recurly.com/page/recurly-v3-api-early-access).

If you were looking for the V2 client, see the [master branch](https://github.com/recurly/recurly-client-python/tree/master) of the recurly-client-python repo.

### Documentation

This library's [python documentation](https://recurly-client-python.readthedocs.io/en/latest/) is hosted on ReadTheDocs. 
It contains the Getting Started guide as well as the reference documentation.

The HTTP documentation for the V3 API can be [found here](https://partner-docs.recurly.com).
